@@ -26,7 +26,7 @@
 #' occs$occID <- 1:nrow(occs)
 #' bgExt <- penvs_bgExtent(occs, bgSel = 'bounding box', bgBuf = 0.5)
 #'
-#' @return A SpatialPolygonsDataFrame object that contains all occurrences from occs
+#' @return A SpatialPolygons object that contains all occurrences from occs
 #' @author Jamie Kass <jamie.m.kass@@gmail.com>
 #' @author Gonzalo E. Pinilla-Buitrago <gepinillab@@gmail.com>
 # @note
@@ -51,6 +51,10 @@ penvs_bgExtent <- function(occs, bgSel, bgBuf, logger = NULL, spN = NULL) {
   # make spatial pts object of original occs and preserve origID
   occs.sp <- sp::SpatialPointsDataFrame(occs.xy, data = occs['occID'])
 
+  # make an sf obj
+  occs.sf <- sf::st_as_sf(occs.xy, coords = c("longitude", "latitude"))
+  occs.sf <- sf::st_union(occs.sf, by_feature = FALSE)
+
   # generate background extent - one grid cell is added to perimeter of each shape
   # to ensure cells of points on border are included
   if (bgSel == 'bounding box') {
@@ -70,22 +74,29 @@ penvs_bgExtent <- function(occs, bgSel, bgBuf, logger = NULL, spN = NULL) {
     bgExt <- sp::SpatialPolygons(list(sp::Polygons(list(sp::Polygon(as.matrix(xy.bord))), 1)))
     msg <- "Study extent: minimum convex polygon."
   } else if (bgSel == 'point buffers') {
-    if (bgBuf == 0) {
+    if (bgBuf <= 0) {
       logger %>%
       writeLog(type = 'error',
-               'Change buffer distance to positive or negative value.')
+               'Change buffer distance to a positive value.')
       return()
     }
-    bgExt <- rgeos::gBuffer(occs.sp, width = bgBuf)
+    bgExt <- sf::st_buffer(occs.sf, dist = bgBuf)
     msg <- paste0("Study extent: buffered points.  Buffered by ", bgBuf, " degrees.")
   }
 
-  if (bgBuf > 0 & bgSel != 'point buffers') {
-    bgExt <- rgeos::gBuffer(bgExt, width = bgBuf)
+  if (bgBuf >= 0 & bgSel != 'point buffers') {
+    bgExt <- sf::st_as_sf(bgExt)
+    bgExt <- sf::st_buffer(bgExt, dist = bgBuf)
     logger %>% writeLog(hlSpp(spN), msg, ' Buffered by ', bgBuf, ' degrees.')
+  } else if (bgBuf < 0 & bgSel != 'point buffers') {
+    logger %>%
+      writeLog(type = 'error',
+               'All localities must be included within extent.
+               Change buffer distance to a positive value.')
+    return()
   } else {
     logger %>% writeLog(hlSpp(spN), msg)
   }
-  bgExt <- methods::as(bgExt, "SpatialPolygonsDataFrame")
+  bgExt <- sf::as_Spatial(bgExt)
   return(bgExt)
 }
