@@ -45,7 +45,7 @@ xfer_area_module_ui <- function(id) {
     actionButton(ns('goTransferArea'), "Transfer"),
     tags$hr(class = "hrDashed"),
     actionButton(ns("goResetXfer"), "Reset", class = 'butReset'),
-    strong(" transferion extent ")
+    strong(" transfer extent ")
   )
 }
 
@@ -117,13 +117,22 @@ xfer_area_module_server <- function(input, output, session, common) {
                                 input$userXfBuf, logger, spN = curSp())
       # ERRORS ####
       # Check that the extents of raster and transfer extent intersects
-      if (!rgeos::gIntersects(polyXf,
-                              methods::as(raster::extent(envs()),
-                                          'SpatialPolygons'))) {
+      polyXf_sfc <- sf::st_as_sfc(polyXf) #convert poly to sfc
+      envs_ext <- methods::as(raster::extent(envs()),'SpatialPolygons')
+      envs_sfc <- sf::st_as_sfc(envs_ext) #convert envs to sfc
+      #set crs to match
+      if (sf::st_crs(polyXf_sfc) != sf::st_crs(envs_sfc)) {
+        sf::st_crs(polyXf_sfc) <- sf::st_crs(envs_sfc)
         logger %>%
-          writeLog(type = 'error', 'Extents do not overlap')
+          writeLog(type = 'error', 'CRS was automatically set to match environmental variables.')
         return()
       }
+      if (!sf::st_intersects(polyXf_sfc, envs_sfc, sparse = FALSE)[1,1]) {
+        logger %>%
+          writeLog(type = 'error', 'Extents do not overlap.')
+        return()
+      }
+
       # METADATA ####
       spp[[curSp()]]$rmm$code$wallace$XfBuff <- input$userXfBuf
       # get extensions of all input files
@@ -158,15 +167,16 @@ xfer_area_module_server <- function(input, output, session, common) {
       return()
     }
     if (is.null(spp[[curSp()]]$transfer$xfExt)) {
-      logger %>% writeLog(type = 'error', 'Select transferion extent first.')
+      logger %>% writeLog(type = 'error', 'Select transfer extent first.')
       return()
     }
     # Check that the extents of raster and transfer extent intersects
-    if (!rgeos::gIntersects(spp[[curSp()]]$transfer$xfExt,
-                            methods::as(raster::extent(envs()),
-                                        'SpatialPolygons'))) {
+      Xfer_sfc <- sf::st_as_sfc(spp[[curSp()]]$transfer$xfExt) #convert xfrExt to sfc
+      envs_ext <- methods::as(raster::extent(envs()),'SpatialPolygons')
+      envs_sfc <- sf::st_as_sfc(envs_ext) #convert envs to sfc
+    if (!sf::st_intersects(Xfer_sfc, envs_sfc, sparse = FALSE)[1,1]) {
       logger %>%
-        writeLog(type = 'error', 'Extents do not overlap')
+        writeLog(type = 'error', 'Extents do not overlap.')
       return()
     }
 
@@ -233,11 +243,11 @@ xfer_area_module_server <- function(input, output, session, common) {
         thr <- stats::quantile(occPredVals, probs = input$trainPresQuantile)
       }
       xferAreaThr <- xferArea > thr
-      logger %>% writeLog(hlSpp(curSp()), "Transferion of model to new area with threshold ",
+      logger %>% writeLog(hlSpp(curSp()), "Transfer of model to new area with threshold ",
                           input$threshold, ' (', formatC(thr, format = "e", 2), ').')
     } else {
       xferAreaThr <- xferArea
-      logger %>% writeLog(hlSpp(curSp()), "Transferion of model to new area with ",
+      logger %>% writeLog(hlSpp(curSp()), "Transfer of model to new area with ",
                           predType, ' output.')
     }
     raster::crs(xferAreaThr) <- raster::crs(envs())
@@ -295,12 +305,12 @@ xfer_area_module_server <- function(input, output, session, common) {
     common$update_component(tab = "Map")
   })
 
-  # Reset Transferion Extent button functionality
+  # Reset Transfer Extent button functionality
   observeEvent(input$goResetXfer, {
     spp[[curSp()]]$polyXfXY <- NULL
     spp[[curSp()]]$polyXfID <- NULL
     spp[[curSp()]]$transfer <- NULL
-    logger %>% writeLog("Reset transferion extent.")
+    logger %>% writeLog("Reset transfer extent.")
   })
 
   return(list(
@@ -337,7 +347,7 @@ xfer_area_module_map <- function(map, common) {
     circleOptions = FALSE, markerOptions = FALSE, circleMarkerOptions = FALSE,
     editOptions = leaflet.extras::editToolbarOptions()
   )
-  # Add just transferion Polygon
+  # Add just transfer Polygon
   req(spp[[curSp()]]$transfer$xfExt)
   polyXfXY <- spp[[curSp()]]$transfer$xfExt@polygons[[1]]@Polygons
   if(length(polyXfXY) == 1) {
@@ -374,7 +384,7 @@ xfer_area_module_map <- function(map, common) {
                 values = mapXferVals, layerId = 'xfer',
                 labFormat = reverseLabel(2, reverse_order = TRUE))
   }
-  # map model prediction raster and transferion polygon
+  # map model prediction raster and transfer polygon
   map %>% clearMarkers() %>% clearShapes() %>% removeImage('xferRas') %>%
     addRasterImage(mapXfer(), colors = rasPal, opacity = 0.7,
                    layerId = 'xferRas', group = 'xfer', method = "ngb")
@@ -398,9 +408,9 @@ xfer_area_module_rmd <- function(species) {
     polyXfID_rmd =  if(!is.null(species$rmm$code$wallace$drawExtPolyXfCoords)){
      species$polyXfID} else {0},
     BgBuf_rmd = species$rmm$code$wallace$XfBuff,
-    ##Determine the type of transferion extent to use correct RMD function
+    ##Determine the type of transfer extent to use correct RMD function
     xfer_area_extent_knit = !is.null(species$rmm$code$wallace$userXfShpParams),
-    ##Use of threshold for transferion
+    ##Use of threshold for transfer
     xfer_area_threshold_knit = !is.null(species$rmm$prediction$transfer$environment1$thresholdSet),
     xfer_thresholdRule_rmd = species$rmm$prediction$transfer$environment1$thresholdRule,
     xfer_threshold_rmd = if (!is.null(species$rmm$prediction$transfer$environment1$thresholdSet)){
